@@ -278,106 +278,44 @@ class SeqLinear(nn.Module):
     """
     Linear layer with weights derived from a weighted sum of rank-1 sequential updates.
     """
-    def __init__(self, d_model, n_heads,
-                 d_conv=4, d_state=None, d_inner=None,
-                 chunk_size=64, device="cpu"):
+    def __init__(self, d_in, d_out, n_heads,
+                 device="cpu"):
         super().__init__()
-        self.d_model = d_model
-        self.d_state = d_state if d_state is not None else d_model
-        self.d_inner = d_inner if d_inner is not None else d_model
+        self.d_in = d_in
+        self.d_out = d_out
         self.n_heads = n_heads
-        self.chunk_size = chunk_size
         self.device = device
         
-        d_in_proj = 2 * self.d_state + self.d_inner + self.n_heads
-        self.in_proj = nn.Linear(d_model, d_in_proj, bias=False, device=device)
-        d_conv_c = 2 * self.d_state + self.d_inner
-        self.conv = nn.Conv1d(
-            in_channels=d_conv_c,
-            out_channels=d_conv_c,
-            kernel_size=d_conv,
-            groups=d_conv_c,
-            padding=d_conv-1,
-            device=device,
-        )
-        self.A = nn.Parameter(torch.empty(n_heads, device=device))
-        self.dt_bias = nn.Parameter(torch.empty(n_heads, device=device))
-        self.out_proj = nn.Linear(self.d_inner, d_model, bias=False, device=device)
+        d_in_proj = d_in + d_out + self.n_heads
+        self.in_proj = nn.Linear(d_in, d_in_proj, bias=False, device=device)
+        self.w_base = nn.Parameter(torch.empty(n_heads, device=device))
         
         self._reset_parameters()
     
     def _reset_parameters(self):
         nn.init.xavier_uniform_(self.in_proj.weight)
-        nn.init.xavier_uniform_(self.out_proj.weight)
-        nn.init.xavier_uniform_(self.conv.weight)
-        nn.init.uniform_(self.A, -0.1, 0.1)
-        
-        if self.conv.bias is not None:
-            nn.init.constant_(self.conv.bias, 0.)
-        if self.in_proj.bias is not None:
-            nn.init.constant_(self.in_proj.bias, 0.)
-        if self.out_proj.bias is not None:
-            nn.init.constant_(self.out_proj.bias, 0.)
+        nn.init.uniform_(self.w_base, -0.1, 0.1)
     
     def bidirectional(self, x):
         bsz, src_len, d_model = x.size()
         
-        x = self.in_proj(x)
+        IOw = self.in_proj(x)
         
-        x, dt = torch.split(
-            x,
+        I, O, w = torch.split(
+            IOw,
             [
-                2 * self.d_state + self.d_inner,
+                self.d_in,
+                self.d_out,
                 self.n_heads,
             ],
             dim=-1
         )
         
-        if cuda_causal_conv1d is not None:
-            x_f = cuda_causal_conv1d(
-                x.transpose(1, 2).contiguous(),
-                self.conv.weight.squeeze(1),
-                bias=self.conv.bias,
-                activation=None,
-            ).transpose(1, 2)
-            x_b = cuda_causal_conv1d(
-                x.flip(1).transpose(1, 2).contiguous(),
-                self.conv.weight.squeeze(1),
-                bias=self.conv.bias,
-                activation=None,
-            ).transpose(1, 2)
-        else:
-            x_f = self.conv(x.transpose(1, 2).contiguous()).transpose(1, 2)[:, :x.size(1)]
-            x_b = self.conv(x.flip(1).transpose(1, 2).contiguous()).transpose(1, 2)[:, :x.size(1)]
-        
-        C_f, B_f, x_f = torch.split(
-            x_f,
-            [
-                self.d_state,
-                self.d_state,
-                self.d_inner,
-            ],
-            dim=-1
-        )
-        C_b, B_b, x_b = torch.split(
-            x_b,
-            [
-                self.d_state,
-                self.d_state,
-                self.d_inner,
-            ],
-            dim=-1
-        )
-        
-        C_f = rearrange(C_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        B_f = rearrange(B_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        x_f = rearrange(x_f, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        
-        C_b = rearrange(C_b, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        B_b = rearrange(B_b, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        x_b = rearrange(x_b, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        
-        decay_f = F.silu(dt * self.A).transpose(1, 2).unsqueeze(-2).repeat(1, 1, src_len, 1)
+        x = rearrange(x, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
+        I = rearrange(I, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
+        O = rearrange(O, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
+
+        decay_f = F.silu(w * self.w_base).transpose(1, 2).unsqueeze(-2).repeat(1, 1, src_len, 1)
         decay_b = decay_f.flip(-1)
         mask = torch.tril(torch.ones(src_len, src_len, dtype=torch.bool, device=self.device), diagonal=-1)
         decay_f = decay_f.masked_fill(~mask, 0.0)
@@ -389,75 +327,53 @@ class SeqLinear(nn.Module):
         decay_b = decay_b.masked_fill(~mask, float('-inf'))
         decay_f = F.softmax(decay_f, dim=-1)
         decay_b = F.softmax(decay_b, dim=-1)
-        out_f = torch.einsum('bthd, bhts, bshd, bshe -> bthe', C_f, decay_f, B_f, x_f)
-        out_b = torch.einsum('bthd, bhts, bshd, bshe -> bthe', C_b, decay_b, B_b, x_b)
+        out_f = torch.einsum('bthd, bhts, bshd, bshe -> bthe', x, decay_f, I, O)
+        out_b = torch.einsum('bthd, bhts, bshd, bshe -> bthe', x, decay_b, I, O)
         
         out = rearrange(out_f + out_b, 'b s h d -> b s (h d)')
-        out = self.out_proj(out)
         return out
     
     def forward(self, x, mode="causal"):
         if mode == "bidirectional": return self.bidirectional(x)
         bsz, src_len, d_model = x.size()
 
-        x = self.in_proj(x)
+        IOw = self.in_proj(x)
         
-        x, dt = torch.split(
-            x,
+        I, O, w = torch.split(
+            IOw,
             [
-                2 * self.d_state + self.d_inner,
+                self.d_in,
+                self.d_out,
                 self.n_heads,
             ],
             dim=-1
         )
         
-        if cuda_causal_conv1d is not None:
-            x = cuda_causal_conv1d(
-                x.transpose(1, 2).contiguous(),
-                self.conv.weight.squeeze(1),
-                bias=self.conv.bias,
-                activation=None,
-            ).transpose(1, 2)
-        else:
-            x = self.conv(x.transpose(1, 2).contiguous()).transpose(1, 2)[:, :x.size(1)]
-        
-        C, B, x = torch.split(
-            x,
-            [
-                self.d_state,
-                self.d_state,
-                self.d_inner,
-            ],
-            dim=-1
-        )
-        
-        C = rearrange(C, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
-        B = rearrange(B, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
         x = rearrange(x, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
+        I = rearrange(I, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
+        O = rearrange(O, 'b s (h d) -> b s h d', h=self.n_heads).contiguous()
         
         if mode == "causal":
-            decay = F.silu(dt * self.A).transpose(1, 2).unsqueeze(-2).repeat(1, 1, src_len, 1)
+            decay = F.silu(w * self.w_base).transpose(1, 2).unsqueeze(-2).repeat(1, 1, src_len, 1)
             mask = torch.tril(torch.ones(src_len, src_len, dtype=torch.bool, device=self.device), diagonal=-1)
             decay = decay.masked_fill(~mask, 0.0)
             decay = -decay.flip(-1).cumsum(-1).flip(-1)
             mask = torch.tril(torch.ones(src_len, src_len, dtype=torch.bool, device=self.device), diagonal=0)
             decay = decay.masked_fill(~mask, float('-inf'))
             decay = F.softmax(decay, dim=-1)
-            out = torch.einsum('bthd, bhts, bshd, bshe -> bthe', C, decay, B, x)
+            out = torch.einsum('bthd, bhts, bshd, bshe -> bthe', x, decay, I, O)
         elif mode == "noncausal":
-            decay = F.softmax(-F.silu(dt * self.A), dim=1)
-            out = torch.einsum('bthd, bsh, bshd, bshe -> bthe', C, decay, B, x)
+            decay = F.softmax(-F.silu(w * self.w_base), dim=1)
+            out = torch.einsum('bthd, bsh, bshd, bshe -> bthe', x, decay, I, O)
 
         out = rearrange(out, 'b s h d -> b s (h d)')
-        out = self.out_proj(out)
         return out
 
 class SeqMLP(nn.Module):
     def __init__(self, emb_dim, input_dim, output_dim,
                  n_layers=1, n_heads=1, dropout=0.0,
-                 d_state=None, d_inner=None, d_conv=4,
                  pos_encoding=False, pos_encoding_max_len=None,
-                 use_embedding=True, weight_tying=False, chunk_size=64,
+                 use_embedding=True, weight_tying=False,
                  mode="causal", device="cpu"):
         super().__init__()
         self.emb_dim = emb_dim
@@ -483,13 +399,16 @@ class SeqMLP(nn.Module):
         self.layers = nn.ModuleList([
             nn.ModuleDict(
                 dict(
-                    mixer=SeqLinear(
-                        d_model=emb_dim,
+                    proj1=SeqLinear(
+                        d_in=emb_dim,
+                        d_out=2*emb_dim,
+                        n_heads=n_heads,
+                        device=device
+                    ),
+                    proj2=SeqLinear(
+                        d_in=emb_dim,
+                        d_out=emb_dim,
                         n_heads=n_heads,
-                        d_state=d_state,
-                        d_inner=d_inner,
-                        d_conv=d_conv,
-                        chunk_size=chunk_size,
                         device=device
                     ),
                     dropout = nn.Dropout(dropout),
@@ -515,8 +434,11 @@ class SeqMLP(nn.Module):
             x = x + self.abs_pos_encoding(pos)
         for layer in self.layers:
             x_norm = layer.norm(x)
-            mixer_out = layer.mixer(x_norm, mode=self.mode)
-            x = x + layer.dropout(mixer_out)
+            yg = layer.proj1(x_norm, mode=self.mode)
+            y, g = torch.chunk(yg, 2, dim=-1)
+            y = F.silu(y) * g
+            y = layer.proj2(y, mode=self.mode)
+            x = x + layer.dropout(y)
         x = self.norm_f(x)
         x = self.out_proj(x)
         return x
\ No newline at end of file
